summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_contents/render_view_host_delegate_helper.cc
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-20 22:05:12 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-20 22:05:12 +0000
commite69bce3dd3e31039bc1072ae2aa63485d094ecd0 (patch)
tree7767051d7c655a481664596160aace7eb59fd419 /chrome/browser/tab_contents/render_view_host_delegate_helper.cc
parent77bc673bf31c32bfdcb1bf139c3a58eace23e3ea (diff)
downloadchromium_src-e69bce3dd3e31039bc1072ae2aa63485d094ecd0.zip
chromium_src-e69bce3dd3e31039bc1072ae2aa63485d094ecd0.tar.gz
chromium_src-e69bce3dd3e31039bc1072ae2aa63485d094ecd0.tar.bz2
Rename WebContentsView* to TabContentsView* in preparation for merging
TabContents and WebContents. This also removes the Destroy method from the print manager's header file. I removed the impl in a previous change but forgot the header. Review URL: http://codereview.chromium.org/90004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@14063 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/tab_contents/render_view_host_delegate_helper.cc')
-rw-r--r--chrome/browser/tab_contents/render_view_host_delegate_helper.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/tab_contents/render_view_host_delegate_helper.cc b/chrome/browser/tab_contents/render_view_host_delegate_helper.cc
index 9268850..5dd3c17 100644
--- a/chrome/browser/tab_contents/render_view_host_delegate_helper.cc
+++ b/chrome/browser/tab_contents/render_view_host_delegate_helper.cc
@@ -23,13 +23,13 @@ void RenderViewHostDelegateViewHelper::CreateNewWindow(int route_id,
base::WaitableEvent* modal_dialog_event, Profile* profile,
SiteInstance* site) {
// Create the new web contents. This will automatically create the new
// WebContentsView. In the future, we may want to create the view separately.
WebContents* new_contents =
new WebContents(profile,
site,
route_id,
modal_dialog_event);
- WebContentsView* new_view = new_contents->view();
+ TabContentsView* new_view = new_contents->view();
// TODO(brettw) it seems bogus that we have to call this function on the
// newly created object and give it one of its own member variables.
@@ -23,13 +23,13 @@ void RenderViewHostDelegateViewHelper::CreateNewWindow(int route_id,
SiteInstance* site) {
// Create the new web contents. This will automatically create the new
- // WebContentsView. In the future, we may want to create the view separately.
+ // TabContentsView. In the future, we may want to create the view separately.
WebContents* new_contents =
new WebContents(profile,